@@ -12,12 +12,12 @@ labels (Int64Tensor[N]): the class label for each ground-truth box
 https://colab.research.google.com/github/benihime91/pytorch_retinanet/blob/master/demo.ipynb#scrollTo=0zNGhr6D7xGN
 
 """
+import glob
 import os
 import pandas as pd
 from skimage import io
 from torch.utils.data import Dataset
 from deepforest import transforms as T
-from deepforest.preprocess import preprocess_image
 
 def get_transform(augment):
     transforms = []
@@ -34,7 +34,7 @@ class TreeDataset(Dataset):
     def __init__(self, csv_file, root_dir, transforms):
         """
         Args:
-            csv_file (string): Path to the csv file with annotations.
+            csv_file (string): Path to a single csv file with annotations.
             root_dir (string): Directory with all the images.
             transform (callable, optional): Optional transform to be applied
                 on a sample.
@@ -42,19 +42,19 @@ class TreeDataset(Dataset):
         self.annotations = pd.read_csv(csv_file)
         self.root_dir = root_dir
         self.transform = transforms
+        self.image_names = self.annotations.image_path.unique()
 
     def __len__(self):
-        return self.annotations.shape[0]
+        return len(self.image_names)
 
     def __getitem__(self, idx):
-        path = self.annotations.loc[idx, "image_path"]
-        img_name = os.path.join(self.root_dir, path)
+        img_name = os.path.join(self.root_dir, self.image_names[idx])
         image = io.imread(img_name)
         image = image/255   
         
         #select annotations
         image_annotations = self.annotations[self.annotations.image_path ==
-                                             path]
+                                             self.image_names[idx]]
         targets = {}
         targets["boxes"] = image_annotations[["xmin", "ymin", "xmax",
                                    "ymax"]].values.astype(float)
@@ -65,4 +65,4 @@ class TreeDataset(Dataset):
         if self.transform:
             image, targets = self.transform(image, targets)
 
-        return image, targets   
+        return self.image_names[idx], image, targets
\ No newline at end of file
