@@ -11,28 +11,31 @@ from deepforest import preprocess
 from deepforest import visualize
 from skimage import io
 
-def predict_image(model, image, score_threshold, return_plot):
+def predict_image(model, image, return_plot, device, iou_threshold=0.1):
     """Predict an image with a deepforest model
     
     Args:
         image: a numpy array of a RGB image ranged from 0-255
         path: optional path to read image from disk instead of passing image arg
         return_plot: Return image with plotted detections
-        score_threshold: float [0,1] minimum probability score to return/plot.
+        device: pytorch device of 'cuda' or 'cpu' for gpu prediction. Set internally.
     Returns:
         boxes: A pandas dataframe of predictions (Default)
         img: The input with predictions overlaid (Optional)
     """        
     image = preprocess.preprocess_image(image)
+    image = image.to(device)
     prediction = model(image)
-    
+        
+    if not device.type=="cpu":
+        prediction = prediction[0].detach().cpu().numpy()
+        
     #return None for no predictions
     if len(prediction[0]["boxes"])==0:
         return None
     
     #This function on takes in a single image.
-    df = visualize.format_predictions(prediction[0])
-    df = df[df.scores > score_threshold]
+    df = visualize.format_boxes(prediction[0])
     
     if return_plot:
         #Matplotlib likes no batch dim and channels first
@@ -42,7 +45,7 @@ def predict_image(model, image, score_threshold, return_plot):
     else:
         return df
     
-def predict_file(model,csv_file,root_dir, savedir):
+def predict_file(model,csv_file,root_dir, savedir, device):
     """Create a dataset and predict entire annotation file
     
     Csv file format is .csv file with the columns "image_path", "xmin","ymin","xmax","ymax" for the image name and bounding box position. 
@@ -52,6 +55,7 @@ def predict_file(model,csv_file,root_dir, savedir):
         csv_file: path to csv file 
         root_dir: directory of images. If none, uses "image_dir" in config
         savedir: Optional. Directory to save image plots.
+        device: pytorch device of 'cuda' or 'cpu' for gpu prediction. Set internally.
     Returns:
         df: pandas dataframe with bounding boxes, label and scores for each image in the csv file
     """    
@@ -60,15 +64,20 @@ def predict_file(model,csv_file,root_dir, savedir):
     
     #Just predict each image once. 
     images = input_csv["image_path"].unique()         
-    
+        
     prediction_list = []
     for path in images:
         image = io.imread("{}/{}".format(root_dir,path))
+        
         image = preprocess.preprocess_image(image)
         
         #Just predict the images, even though we have the annotations
-        prediction = model(image)
-        prediction = visualize.format_predictions(prediction[0])
+        if not device.type=="cpu":
+            image = image.to(device)
+        
+        prediction = model(image)        
+        
+        prediction = visualize.format_boxes(prediction[0])
         prediction["image_path"] = path
         prediction_list.append(prediction)
         
@@ -84,12 +93,12 @@ def predict_file(model,csv_file,root_dir, savedir):
     return df
 
 def predict_tile(model,
+                 device,
                  raster_path=None,
                  image=None,
                  patch_size=400,
                  patch_overlap=0.05,
                  iou_threshold=0.15,
-                 score_threshold=0,
                  return_plot=False,
                  use_soft_nms = False,
                  sigma = 0.5,
@@ -105,7 +114,6 @@ def predict_tile(model,
             following openCV convention
         patch_size: patch size default400,
         patch_overlap: patch overlap default 0.15,
-        score_threshold (float): minimum score to include in predictions
         iou_threshold: Minimum iou overlap among predictions between
             windows to be suppressed. Defaults to 0.5.
             Lower values suppress more boxes at edges.
@@ -113,6 +121,7 @@ def predict_tile(model,
         use_soft_nms: whether to perform Gaussian Soft NMS or not, if false, default perform NMS. 
         sigma: variance of Gaussian function used in Gaussian Soft NMS
         thresh: the score thresh used to filter bboxes after soft-nms performed
+        device: pytorch device of 'cuda' or 'cpu' for gpu prediction. Set internally.
     
     Returns:
         boxes (array): if return_plot, an image.
@@ -134,21 +143,24 @@ def predict_tile(model,
         #crop window and predict
         crop = image[windows[index].indices()] 
         
-        #crop is RGB channel order, change to BGR
-        crop = crop[...,::-1]
+        #crop is RGB channel order, change to BGR?
         boxes = predict_image(model=model,
                               image=crop,
                               return_plot=False,
-                              score_threshold=score_threshold)
-        
-        #transform the coordinates to original system
-        xmin, ymin, xmax, ymax = windows[index].getRect()
-        boxes.xmin = boxes.xmin + xmin
-        boxes.xmax = boxes.xmax + xmin
-        boxes.ymin = boxes.ymin + ymin
-        boxes.ymax = boxes.ymax + ymin
-
-        predicted_boxes.append(boxes)
+                              device=device)
+        if not boxes is None:
+            #transform the coordinates to original system
+            xmin, ymin, xmax, ymax = windows[index].getRect()
+            boxes.xmin = boxes.xmin + xmin
+            boxes.xmax = boxes.xmax + xmin
+            boxes.ymin = boxes.ymin + ymin
+            boxes.ymax = boxes.ymax + ymin
+    
+            predicted_boxes.append(boxes)
+    
+    if len(predicted_boxes) == 0:
+        print("No predictions made, returning None")
+        return None
     
     predicted_boxes = pd.concat(predicted_boxes)
     # Non-max supression for overlapping boxes among window
