@@ -54,14 +54,14 @@ def use_release(save_dir=os.path.join(_ROOT, "data/"), prebuilt_model="NEON"):
     _json = json.loads(
         urllib.request.urlopen(
             urllib.request.Request(
-                'https://api.github.com/repos/Weecology/DeepForest/releases/latest',
+                'https://api.github.com/repos/Weecology/DeepForest-pytorch/releases/latest',
                 headers={'Accept': 'application/vnd.github.v3+json'},
             )).read())
     asset = _json['assets'][0]
     url = asset['browser_download_url']
 
     # Naming based on pre-built model
-    output_path = os.path.join(save_dir, prebuilt_model + ".h5")
+    output_path = os.path.join(save_dir, prebuilt_model + ".pt")
 
     # Check the release tagged locally
     try:
@@ -123,8 +123,6 @@ def xml_to_annotations(xml_path):
     label = []
 
     if type(tile_xml) == list:
-        treeID = np.arange(len(tile_xml))
-
         # Construct frame if multiple trees
         for tree in tile_xml:
             xmin.append(tree["bndbox"]["xmin"])
@@ -133,9 +131,6 @@ def xml_to_annotations(xml_path):
             ymax.append(tree["bndbox"]["ymax"])
             label.append(tree['name'])
     else:
-        # One tree
-        treeID = 0
-
         xmin.append(tile_xml["bndbox"]["xmin"])
         xmax.append(tile_xml["bndbox"]["xmax"])
         ymin.append(tile_xml["bndbox"]["ymin"])
@@ -160,6 +155,60 @@ def xml_to_annotations(xml_path):
     })
     return (annotations)
 
+def shapefile_to_annotations(shapefile, rgb, savedir="."):
+    """
+    Convert a shapefile of annotations into annotations csv file for DeepForest training and evaluation
+    Args:
+        shapefile: Path to a shapefile on disk. If a label column is present, it will be used, else all labels are assumed to be "Tree"
+        rgb: Path to the RGB image on disk
+        savedir: Directory to save csv files
+    Returns:
+        results: a pandas dataframe
+    """
+    #Read shapefile
+    gdf = gpd.read_file(shapefile)
+    
+    #get coordinates
+    df = gdf.geometry.bounds
+    
+    #raster bounds
+    with rasterio.open(rgb) as src:
+        left, bottom, right, top = src.bounds
+        resolution = src.res[0]
+        
+    #Transform project coordinates to image coordinates
+    df["tile_xmin"] = (df.minx - left)/resolution
+    df["tile_xmin"] = df["tile_xmin"].astype(int)
+    
+    df["tile_xmax"] = (df.maxx - left)/resolution
+    df["tile_xmax"] = df["tile_xmax"].astype(int)
+    
+    #UTM is given from the top, but origin of an image is top left
+    
+    df["tile_ymax"] = (top - df.miny)/resolution
+    df["tile_ymax"] = df["tile_ymax"].astype(int)
+    
+    df["tile_ymin"] = (top - df.maxy)/resolution
+    df["tile_ymin"] = df["tile_ymin"].astype(int)    
+    
+    #Add labels is they exist
+    if "label" in gdf.columns:
+        df["label"] = gdf["label"]
+    else:
+        df["label"] = "Tree"
+    
+    #add filename
+    df["image_path"] = os.path.basename(rgb)
+    
+    #select columns
+    result = df[["image_path","tile_xmin","tile_ymin","tile_xmax","tile_ymax","label"]]
+    result = result.rename(columns={"tile_xmin":"xmin","tile_ymin":"ymin","tile_xmax":"xmax","tile_ymax":"ymax"})
+    
+    #ensure no zero area polygons due to rounding to pixel size
+    result = result[~(result.xmin == result.xmax)]
+    result = result[~(result.ymin == result.ymax)]
+    
+    return result
 
 def round_with_floats(x):
     """Check if string x is float or int, return int, rounded if needed."""
@@ -177,9 +226,6 @@ def round_with_floats(x):
 
     return result
 
-def load_saved_model():
-    pass
-
 def check_file(df):
     """Check a file format for correct column names and structure"""
     
